@@ -10,13 +10,14 @@ with 'Vote::Count::TieBreaker',
   'Vote::Count::Approval',
   'Vote::Count::Borda',
   'Vote::Count::Log',
-  'Vote::Count::Range';
+  'Vote::Count::Score',
+  ;
 
 use Vote::Count::RankCount;
 
 no warnings 'experimental';
 use List::Util qw( min max sum );
-use TextTableTiny qw/generate_markdown_table/;
+use Vote::Count::TextTableTiny qw/generate_markdown_table/;
 use Sort::Hash;
 
 # use Try::Tiny;
@@ -25,13 +26,13 @@ use Sort::Hash;
 
 use YAML::XS;
 
-our $VERSION='0.02430';
+our $VERSION='1.05';
 
 =head1 NAME
 
 Vote::Count::Matrix
 
-=head1 VERSION 0.02430
+=head1 VERSION 1.05
 
 =cut
 
@@ -43,12 +44,6 @@ has BallotSet => (
   isa      => 'HashRef',
 );
 
-has BallotSetType => (
-  is      => 'ro',
-  isa     => 'Str',
-  default => 'rcv',
-);
-
 has Active => (
   is      => 'rw',
   isa     => 'HashRef',
@@ -74,8 +69,8 @@ sub _untie ( $I, $A, $B ) {
 }
 
 sub _pairwinner_rcv ( $ballots, $A, $B ) {
-  my $countA  = 0;
-  my $countB  = 0;
+  my $countA = 0;
+  my $countB = 0;
 FORVOTES:
   for my $b ( keys $ballots->%* ) {
     for my $v ( values $ballots->{$b}{'votes'}->@* ) {
@@ -89,7 +84,7 @@ FORVOTES:
       }
     }
   }    # FORVOTES
-  return ( $countA, $countB);
+  return ( $countA, $countB );
 }
 
 sub _conduct_pair ( $I, $A, $B ) {
@@ -97,11 +92,11 @@ sub _conduct_pair ( $I, $A, $B ) {
   my $countA  = 0;
   my $countB  = 0;
   $I->logv("Pairing: $A vs $B");
-  if ( $I->BallotSet()->{'options'}{'range'}) {
+  if ( $I->BallotSet()->{'options'}{'range'} ) {
     ( $countA, $countB ) = $I->RangeBallotPair( $A, $B );
   }
   else {
-    ( $countA, $countB ) = _pairwinner_rcv ( $ballots, $A, $B );
+    ( $countA, $countB ) = _pairwinner_rcv( $ballots, $A, $B );
   }
   my %retval = (
     $A       => $countA,
@@ -265,9 +260,10 @@ GREATESTLOSSLOOP:
   return $bigloss;
 }
 
-sub RankGreatestLoss ( $self ) {
+sub RankGreatestLoss ( $self, $active = undef ) {
   my %loss = ();
-  for my $A ( keys $self->Active()->%* ) {
+  $active = $self->Active() unless defined $active;
+  for my $A ( keys $active->%* ) {
     $loss{$A} = $self->GreatestLoss($A);
   }
   return Vote::Count::RankCount->Rank( \%loss );
@@ -411,7 +407,7 @@ sub PairingVotesTable ( $self ) {
 
 =head1 Win-Loss Matrix
 
-Condorcet Pairwise Methods require a Win-Loss Matrix. This object takes an RCV BallotSet with an optional Active list and returns the Matrix as an Object. The Ojbect is capable of Scoring itself, Calculating a Smith Set, and identifying Condorcet Winners and Losers.
+Condorcet Pairwise Methods require a Win-Loss Matrix. This object takes an RCV BallotSet with an optional Active list and returns the Matrix as an object. The object is capable of Scoring itself, Calculating a Smith Set, and identifying Condorcet Winners and Losers.
 
 
 =head1 SYNOPSIS
@@ -440,10 +436,7 @@ Parameters:
 
 A Ballot Set reference as generated by ReadBallots, which can be retrieved from a Vote::Count object via the ->BallotSet() method.
 
-
-=head3 BallotSetType (future use)
-
-Defaults to rcv. Currently rcv is the only type supported. In the future the Matrix may be able to deal directly with Range Ballots.
+Both Ranked Choice and Range BallotSets are supported.
 
 
 =head3 Active (optional)
@@ -453,7 +446,7 @@ A hash reference with active choices as the keys. The default value is all of th
 
 =head3 Logging (optional)
 
-Has the logging methods of Vote::Count::Log.
+Has the logging methods of L.
 
 
 =head1 Methods
