@@ -12,17 +12,17 @@ use Data::Printer;
 
 # ABSTRACT: Read Ballots for Vote::Count. Toolkit for vote counting.
 
-our $VERSION='0.02430';
+our $VERSION='1.05';
 
 =head1 NAME
 
 Vote::Count::ReadBallots
 
-=head1 VERSION 0.02430
+=head1 VERSION 1.05
 
 =head1 SYNOPSIS
 
-  Vote::Count::ReadBallots 'read_ballots';
+  Vote::Count::ReadBallots;
 
   my $data1 = read_ballots('t/data/data1.txt');
 
@@ -30,6 +30,8 @@ Vote::Count::ReadBallots
 
 Reads a file containing vote data. Retruns a HashRef of a Vote::Count BallotSet.
 
+All public methods are exported.
+
 =head1 BallotSet Data Structure
 
     ballots   {
@@ -76,15 +78,45 @@ Write out a ballotset. Useful for creating a compressed version of a raw file.
 
 =head1 Range Ballots
 
-...
+Range Ballots are supported in both JSON and YAML format. The read method doesn't perform validation like B<read_ballots> does.
 
-=head2 Other Formats
+=head2 Range Ballot Format in JSON
 
-It is planned to add support in the future for ranged voting. JSON, XML, and YAML formats may also be provided in the future.
+  {
+    "choices": [
+      "TWEEDLEDEE",
+      "TWEEDLEDUM",
+      "HUMPTYDUMPTY"
+    ],
+    "ballots": [
+      {
+        "votes": {
+          "TWEEDLEDEE": 1,
+          "TWEEDLEDUM": 1,
+          "HUMPTYDUMPTY": 3
+        },
+        "count": 3
+      }
+    ],
+    "depth": 3
+  }
+
+=head2 read_range_ballots
+
+Requires a parameter of a JSON or YAML file. The second parameter may be either 'json' or 'yaml', defaulting to 'json'.
+
+  my $BestFastFood = read_range_ballots('t/data/fastfood.range.json');
+  my $BestFastFood = read_range_ballots('t/data/fastfood.range.yml', 'yaml');
+
+=head2 write_range_ballots
+
+Takes three parameters, a BallotSet, a file location, and a value of 'json' or 'yaml'. The first two parameters are required, the third defaults to 'json'.
+
+  write_range_ballots( $BestFastFood, '/tmp/fast.json', 'json' );
 
 =cut
 
-use Exporter::Easy ( OK =>
+use Exporter::Easy ( EXPORT =>
     [qw( read_ballots write_ballots read_range_ballots write_range_ballots)],
 );
 
@@ -99,8 +131,6 @@ sub _choices ( $choices ) {
   return \%C;
 }
 
-## Add ballotscount !
-
 sub read_ballots( $filename ) {
   my %data = (
     'choices'   => undef,
